<template>
  <a-card
    :bordered="false"
    title="故障报修"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="单据号">
              <a-input
                placeholder="请输入单据号"
                v-model="queryParam.num"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="设备编码">
              <a-input
                placeholder="请输入设备编码"
                v-model="queryParam.equipmentNum"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
    </div>

    <div>
      <a-table
        ref="table"
        size="middle"
        :scroll="{ x: 'calc(1900px + 50%)', y: 900 }"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        @change="handleTableChange"
        :customRow="clickThenSelect"
      >
        <!-- :rowSelection="rowSelection" -->
        <!-- :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }" -->

        <!-- <template
          slot="htmlSlot"
          slot-scope="text"
        >
          <div v-html="text"></div>
        </template>
        <template
          slot="imgSlot"
          slot-scope="text,record"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无图片</span>
          <img
            v-else
            :src="getImgView(text)"
            :preview="record.id"
            height="25px"
            alt=""
            style="max-width:80px;font-size: 12px;font-style: italic;"
          />
        </template>
        <template
          slot="fileSlot"
          slot-scope="text"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)"
          >
            下载
          </a-button>
        </template> -->

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a-popconfirm
            v-if="record.status == '1' || record.status == '4'"
            title="确认提交吗?"
            @confirm="() =>handleCommit(record, 'commit')"
          >
            <a>提交</a>
          </a-popconfirm>
          <a-popconfirm
            v-if="record.status == '2'"
            title="确认撤回吗?"
            @confirm="() =>handleCommit(record, 'back')"
          >
            <a>撤回</a>
          </a-popconfirm>

          <a-divider
            v-if="record.status == '1' || record.status == '2' || record.status == '4'"
            type="vertical"
          />
          <a
            v-if="record.status == '1' || record.status == '4'"
            @click="handleEdit(record)"
          >编辑</a>
          <a
            v-if="record.status == '2'"
            @click="handleApprove(record)"
          >审批</a>
          <a-divider
            v-if="record.status == '1' || record.status == '2' || record.status == '4'"
            type="vertical"
          />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item v-if="record.status == '1'">
                <a-popconfirm
                  v-if="record.status == '1'"
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
              <a-menu-item v-if="record.status == '3' || record.status == '4'">
                <a-popconfirm
                  v-if="record.status == '3' || record.status == '4'"
                  title="确认撤销吗?"
                  @confirm="() =>handleFinish(record, 'revoke')"
                >
                  <a>撤销</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <a-tabs
      type="card"
      defaultActiveKey="1"
    >
      <a-tab-pane
        tab="故障描述"
        key="1"
      >
        <div
          class="table-operator"
          style="margin-top: 0px"
        >
          <FaultDescriptionList ref="FaultDescriptionList" />
        </div>

      </a-tab-pane>
    </a-tabs>

    <malfunction-repair-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></malfunction-repair-modal>
    <approvel-modal
      ref='approvalModalForm'
      @ok='approvalModalFormOk'
      @cancel='approvalModalFormOk'
    ></approvel-modal>
  </a-card>
</template>
  
<script>

import '@/assets/less/TableExpand.less'
import { putAction, getAction } from '@/api/manage'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import MalfunctionRepairModal from './modules/malfunctionRepair/MalfunctionRepaireModal'
import FaultDescriptionList from './modules/malfunctionRepair/FaultDescriptionList'
import ApprovelModal from './modules/malfunctionRepair/ApprovelModal'

export default {
  name: 'MalfunctionRepairList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    MalfunctionRepairModal,
    FaultDescriptionList,
    ApprovelModal
  },
  data() {
    return {
      description: '故障报修',
      queryParam: { delflag: 0 },
      selectedRowKeys: [],
      selectionRows: [],
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '状态',
          align: "center",
          dataIndex: 'statusName',
        },
        {
          title: '单据号',
          align: "center",
          dataIndex: 'num'
        },
        {
          title: '设备编码',
          align: "center",
          dataIndex: 'equipmentNum'
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName',
        },
        {
          title: '设备型号',
          align: "center",
          dataIndex: 'equipmentModel',
        },
        {
          title: '规格',
          align: "center",
          dataIndex: 'equipmentSpecification',
        },
        {
          title: '使用部门',
          align: "center",
          dataIndex: 'departName',
        },
        {
          title: '紧急程度',
          align: "center",
          dataIndex: 'urgencyName',
        },
        {
          title: '故障描述',
          align: "center",
          dataIndex: 'faultDescription'
        },
        // {
        //   title: '故障拍照',
        //   align: "center",
        //   dataIndex: 'photo',
        //   scopedSlots: { customRender: 'imgSlot' }
        // },
        {
          title: '故障原因',
          align: "center",
          dataIndex: 'faultReason'
        },
        {
          title: '故障时间',
          align: "center",
          dataIndex: 'faultTime'
        },
        {
          title: '是否停机待修',
          align: "center",
          dataIndex: 'isStopName',
        },
        {
          title: '创建人',
          align: "center",
          dataIndex: 'createBy'
        },
        {
          title: '创建时间',
          align: "center",
          dataIndex: 'createTime',
        },
        {
          title: '备注',
          align: "center",
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          fixed: "right",
          width: 200,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/eam/equipmentReportRepair/getReportRepairList",
        delete: "/eam/equipmentReportRepair/delete",
        deleteBatch: "/eam/equipmentReportRepair/deleteBatch",
        exportXlsUrl: "/eam/equipmentReportRepair/exportXls",
        importExcelUrl: "eam/equipmentReportRepair/importExcel",
        edit: "/eam/equipmentReportRepair/edit",
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
    }
  },
  created() {

  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    },
    rowSelection() {
      return {
        type: 'checkbox',
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys;
          this.onSelectChange(selectedRowKeys, selectedRows);
        },
        getCheckboxProps(record) {
          return ({
            props: {
              // disabled: !(record.equipmentCategoryDtlList.length == 0),
            }
          })
        },
        selectedRowKeys: this.selectedRowKeys,
      };
    },
  },
  methods: {

    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(","), [record]);
          }
        }
      }
    },

    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      var params = this.getQueryParams() //查询条件
      this.loading = true
      getAction(this.url.list, params)
        .then(res => {
          if (res.success) {
            //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
            this.dataSource = res.result.records || res.result
            if (res.result.total) {
              this.ipagination.total = res.result.total
            } else {
              this.ipagination.total = 0
            }
            //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          } else {
            this.$message.warning(res.message)
          }
        })
        .finally(() => {
          this.loading = false
          this.onClearSelected()
          this.$refs.FaultDescriptionList.faultId = '-1'
        })
    },

    onSelectChange(selectedRowKeys, selectionRows) {
      this.selectedRowKeys = selectedRowKeys;
      this.selectionRows = selectionRows;
      if (selectedRowKeys.length == 1) {
        this.$refs.FaultDescriptionList.faultId = selectedRowKeys[0]
      } else {
        this.$refs.FaultDescriptionList.faultId = '-1'
      }
    },


    handleCommit(record, type) {
      type == 'commit' ? record.status = '2' : record.status = '1'
      putAction(this.url.edit, record).then(res => {
        if (res.success) {
          if (type === 'commit') {
            this.$message.success("提交成功！");
          } else {
            this.$message.success("撤回成功！");
          }

          this.loadData();
        } else {
          this.$message.warning(res.message);
        }
      })
    },

    handleFinish(record, type) {
      if (type == 'agree') {
        record.status = '3'
      } else if (type == 'reject') {
        record.status = '4'
      } else if (type == 'revoke') {
        record.status = '2'
      }
      putAction(this.url.edit, record).then(res => {
        if (res.success) {
          this.$message.success("确认成功！");
          this.loadData();
        } else {
          this.$message.warning(res.message);
        }
      })
    },
    handleApprove: function (record) {
      let edit
      edit = this.url.edit
      this.$refs.approvalModalForm.showModals(record, edit, '3', '4')
      this.$refs.approvalModalForm.title = '审批'
      this.$refs.approvalModalForm.disableSubmit = false

    },
    approvalModalFormOk() {
      // 通过/驳回时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()
    },

    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
    },

    searchQuery() {
      this.loadData(1)
      this.onClearSelected()
      this.$refs.FaultDescriptionList.faultId = '-1'
    },

    searchReset() {
      this.queryParam = {}
      this.loadData(1)
      this.onClearSelected()
      this.$refs.FaultDescriptionList.faultId = '-1'
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>